Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1448)

Unified Diff: ui/events/gesture_detection/motion_event.h

Issue 1147083005: Separate motion event touch geometry orientation from stylus orientation. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Aura Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/events/blink/blink_event_util.cc ('k') | ui/events/gesture_detection/motion_event_buffer_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/events/gesture_detection/motion_event.h
diff --git a/ui/events/gesture_detection/motion_event.h b/ui/events/gesture_detection/motion_event.h
index a6028fbdee52c3feb6394960f08ae0b563119270..40b7cd3fa2d387cbc9cb99d0312730aae933aad2 100644
--- a/ui/events/gesture_detection/motion_event.h
+++ b/ui/events/gesture_detection/motion_event.h
@@ -60,7 +60,7 @@ class GESTURE_DETECTION_EXPORT MotionEvent {
virtual float GetRawY(size_t pointer_index) const = 0;
virtual float GetTouchMajor(size_t pointer_index) const = 0;
virtual float GetTouchMinor(size_t pointer_index) const = 0;
- virtual float GetOrientation(size_t pointer_index) const = 0;
+ virtual float GetTouchOrientation(size_t pointer_index) const = 0;
virtual float GetPressure(size_t pointer_index) const = 0;
virtual ToolType GetToolType(size_t pointer_index) const = 0;
virtual int GetButtonState() const = 0;
@@ -92,9 +92,9 @@ class GESTURE_DETECTION_EXPORT MotionEvent {
float GetTouchMajor() const { return GetTouchMajor(0); }
float GetTouchMinor() const { return GetTouchMinor(0); }
- // Returns the orientation of the major axis clockwise from vertical, in
- // radians. The return value lies in [-PI/2, PI/2].
- float GetOrientation() const { return GetOrientation(0); }
+ // Returns the orientation of the touch major axis clockwise from vertical,
+ // in radians. The return value lies in [-PI/2, PI/2].
+ float GetTouchOrientation() const { return GetTouchOrientation(0); }
float GetPressure() const { return GetPressure(0); }
ToolType GetToolType() const { return GetToolType(0); }
« no previous file with comments | « ui/events/blink/blink_event_util.cc ('k') | ui/events/gesture_detection/motion_event_buffer_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698